@@ -11,3 +11,7 @@ class DjangoPuzzleConfig(AppConfig):
             raise ImproperlyConfigured(
                 "prune_captcha: vous devez définir PUZZLE_IMAGE_STATIC_PATH dans settings.py"
             )
+        if not hasattr(settings, "PUZZLE_HINT_TEXT"):
+            raise ImproperlyConfigured(
+                "prune_captcha: vous devez définir PUZZLE_HINT_TEXT  dans settings.py"
+            )
